* File of the Project "1153" - 4_data_annual.do
* Content: Collapse monthly into annual panel

clear
cap log close

log using "$log/4_data_annual.log", replace

use "$data/monthly.dta", clear

gen calmn=month(stichtag)
gen calyr=year(stichtag)
gen caldate=mofd(stichtag)
*xtset persnr caldate, monthly
sort persnr caldate

*** generate indicator for job loss and job found

*employed only if employed subject to social security and not minijob
gen emp=(erwstat==101) 

*jobloss if employment ends
bysort persnr: gen jobloss=(emp[_n]==1 & emp[_n+1]==0 & persnr[_n]==persnr[_n+1]) 
*someone also lost their job if employed in previous spell but the subsequent spell is more than 2 months away 
bysort persnr: replace jobloss=1 if(stichtag[_n+1]-stichtag[_n]>62 & emp[_n]==1  & persnr[_n]==persnr[_n+1]) 

bysort persnr: gen jobfound=(emp[_n-1]==0 & emp[_n]==1 & persnr[_n-1]==persnr[_n]) // job found ==1 in the month the worker starts work again
bysort persnr: replace jobfound=1 if(stichtag[_n]-stichtag[_n-1]>62 & emp[_n]==1 & emp[_n-1]==1 & persnr[_n]==persnr[_n-1])


*************************************************************************************************************
* generate main wage observation for a year: wage during full time employment in jan	*
*************************************************************************************************************

gen avw = tentgelt if (emp==1 & stib!=8 & stib!=9)

***********************************
* Alternative wage measure		  *
***********************************

*average wage during full time employment
bys persnr calyr (caldate): egen avw2=mean(tentgelt) if(emp==1 & stib!=8 & stib!=9)

*save "$data/monthly_final.dta", replace

*********************************
* Turning into Annual Panel 	*
*********************************

label language en

* save variable labels
 foreach v of var * {
	local l`v' : variable label `v'
        if `"`l`v''"' == "" {
 		local l`v' "`v'"
  	}
 }

rename jobloss jobloss2
rename jobfound jobfound2

bys persnr calyr: egen jobloss=max(jobloss2) // 1 if at least one jobloss in a given year
bys persnr calyr: egen jobfound=max(jobfound2) // 1 if at least one jobfound in a given year

drop jobloss2 jobfound2

*now we just keep the spell overlapping the jan reference date
keep if calmn==1

*compute age, age bins, broad age groups
gen age=calyr-gebjahr
xtile age_bin = age, nquantiles(10)
label var age_bin "Age Decile"
xtile age_bin_2 = age, nquantiles(5)
label var age_bin_2 "Age Quintile"

*tenure
quietly gen tage_job_yearly=tage_job/365
label var tage_job_yearly "Job Tenure"
xtile ten_bin = tage_job_yearly, nquantiles(10)
label var ten_bin "Tenure Decile"

* reassign variable labels
 foreach v of var * {
	label var `v' "`l`v''"
 }

label var calyr "Year"
label var jobloss "Lost a job this year"
label var jobfound "Found a job this year"
label var avw "Wage at reference spell"
label var avw2 "Average wage in year"
label var age "Age"

* reassign value labels
local list beruf bild frau nation_gr wo_bula estat8tv //  ausbildung list of variables that have value labels
foreach variable of local list {
	label values `variable' `variable'_en
}

*** Merge Price Index and compute real wages and earnings
merge n:1 calyr using "$orig/cpi2000_oecd.dta"
drop if _merge==2 //drop years not in the sample
drop _merge

replace avw=avw/cpi
replace avw2=avw2/cpi
replace tentgelt=tentgelt/cpi

** create variable for clustering and grouping
egen estyear=group(betnr calyr)
egen estocc=group(betnr beruf)
egen estage=group(betnr age_bin_2)

xtset persnr calyr, yearly

save "$data/annual.dta", replace
