* File of the Project "1153" - 5_coworkFers.do
* Content: 	1) Select Establishments that are contained in the establishment panel, add info on unionazation, mass layoffs, job loss, movers, clean wages, construct and clean various wage growth measures

clear
set more off
cap log close

log using "$log/5_coworkers_a.log", replace


* load the annual panel dataset
use "$data/annual.dta", clear

******************************************************************************************
* First we select panelcase establishments
******************************************************************************************
merge m:1 idnum using "$orig/iabbp_2008.dta" // this load the IAB establishment panel 2008 to identify panel cases, ie the establishments where we see the full workforce

gen pnlcase=[pan00_08=="P"] // panel case estbalishment identifiers

drop _merge

merge m:1 idnum using "$orig/iabbp_2000.dta" // this load the IAB establishment panel 2000 to identify firms that have collective bargaining agreement in 00 (h42 through h44proz)

keep persnr calyr idnum betnr age frau stib erw bild beruf wo_bula avw avw2 ///
	jobloss jobfound tage* nation_gr  estat8tv pnlcase tentgelt avw2 ///
	estyear estocc estage h42 h43 h44 h44proz age_bin age_bin_2 ten_bin grund

******************************************************************************************
* Add information on mass layoffs at the establishments
******************************************************************************************

merge m:1 betnr calyr using "$data/masslayoff.dta"
drop if _merge==2
drop _merge

******************************************************************************************
* Clean Wage Observations from zeros, missings, and outliers
******************************************************************************************
local pay "avw"
foreach p of local pay {

replace `p'=. if `p'==0 //drop 0 wage observations
replace `p'=.n if `p'==.
//windsorize
foreach yy of numlist 1993/2010{
centile `p' if calyr==`yy', centile(1 99.9) //deliberate asymmetry b/c censoring
local lower=r(c_1)
local upper=r(c_2)
replace `p'=.n if `p'<`lower' & `p'!=.n & calyr==`yy'
replace `p'=.n if `p'>`upper' & `p'!=.n & calyr==`yy'
}
}

******************************************************************************************
* The next block throws out all observations without an observed wage when employed subject to social securtiy
******************************************************************************************

* before, we register whether there's apprentices in team
gen voc_ind=0
replace voc_ind=1 if stib==0
bys betnr calyr: egen apprent1=max(voc_ind) //establishment with apprentices
bys betnr beruf calyr: egen apprent2=max(voc_ind) //team with appr

count
drop if avw==.n //throw out observations where wages are unobserved
count

****************************************************************************
	* Calculate various wage change measures
****************************************************************************

xtset persnr calyr

quietly{

	local fes "1 2 3 5 10"
		foreach c of local fes {
			gen wg`c'=(f`c'.avw/avw)^(1/`c')-1 // annualized growth rate
			gen wf`c'=f`c'.avw // wage n years ahead

			** Eliminating permilltiles
			local wm "wg wf"
				foreach w of local wm {
				replace `w'`c'=.n if `w'`c'==.
				centile `w'`c', centile(.1 99.9)
				local lower=r(c_1)
				local upper=r(c_2)
				gen `w'`c'_extr=0
				replace `w'`c'_extr=1 if `w'`c'!=.n & (`w'`c'<`lower' | `w'`c'>`upper')
			}
		}
}

	display _newline "Wage growth 1, 3, 5, 10 years ahead"
	tabstat wg1 wg3 wg5 wg10, stat(mean sd p10 p50 p90 N) col(stats)


****************************************************************************
	* Additional Variables needed
****************************************************************************

	** Assign Wage Decile
	gen wpct=0
	forval yy=1999/2009{
	xtile wpct_temp = avw if calyr==`yy', nquantiles(10)
	replace wpct=wpct_temp if calyr==`yy'
	drop wpct_temp
	}

	** gen indicators for job loss last year (for job loss regressions)
	gen calyr_ly=L.calyr
	gen jobloss_ly=L.jobloss
	gen masslo_ly=L.masslo

	** gen indicators for mover regressions
	gen betnr_ny=F1.betnr
	gen samefirm_1=betnr_ny==float(betnr)

	local dur "2 3 5 10"
	foreach d of local dur{
	replace betnr_ny=F`d'.betnr
	gen samefirm_`d'=betnr_ny==float(betnr)
	}
	drop betnr_ny

******************************************************************************************
* Flag censored data
******************************************************************************************
* let data reveal the "masspoints" indiacating the ceilings in east and west
* split the wage distribution in bins  - then flag the two bins with most people as the two censoring levels

* create the bins
local interval_lower = 90
local interval_upper = 165
local bin_length = .5
local num_bins = (`interval_upper' - `interval_lower')/`bin_length'

*Wage_level will assign workers to bins
gen wage_level = 0
replace wage_level = `num_bins' + 1 if avw>= `interval_upper' // groups all those above the upper threshold into the highest bin

*Assign wage_level for other people inside [interval_lower, interval_upper]
forvalues i = 1(1)`num_bins' {
  replace wage_level = `i' if avw >= (`interval_lower' - `bin_length' +`i'*`bin_length') & avw < (`interval_lower'+`i'*`bin_length')
}

replace wage_level=. if (avw==. | avw==.n)
*Count the frequency of the wage level
bysort calyr wage_level : gen counts = _N if wage_level>0 & wage_level!=.

*get the count of the most frequent salary interval and the second most salary interval
by calyr: egen maxcount = max(counts)
by calyr: egen sec_maxcount = max(counts) if counts < maxcount

*have the indicator indicating whether the salary is censored
gen cens = 0
replace cens = 1 if counts == maxcount | counts == sec_maxcount
replace cens = 0 if wage_level==0 | wage_level==.

* this shows the estimated real top-coding thresholds
noi bys calyr: sum avw if cens==1, det

* indicator of firms with censored workers
bys betnr calyr: egen firmcens= max(cens)
bys betnr beruf calyr: egen teamcens= max(cens)
sum firmcens // workers in firms with top-coding

bys betnr calyr: gen firmcens_ind = firmcens if _n==1
sum firmcens_ind
matlist r(mean)
* fraction of firms with at least 1 worker top coded
noi bys calyr: sum firmcens_ind

rename firmcens top_code1
rename teamcens top_code2

drop wage_level counts maxcount sec_maxcount

*** Save dataset
compress
xtset persnr calyr
save "$data/regression_sample.dta", replace
