* File of the Project "1153" - 5_coworkFers.do
* Content: 	Construct summary stats for teams (size, wage structure) and the wage distribution

*** This file report several summary statistics and in particular prints several histograms for the wage, establishment size, .. distribution (with the number of observations recorded)

clear
set more off
cap log close

log using "$log/5_coworkers_b.log", replace

******************************************************************************************
* Constructing Peer Groups, Computing Summary Stats
******************************************************************************************
local cut "1 2"
foreach g of local cut{

if `g'==2{
	display _newline "THIS IS WHERE THE RESULTS FOR SECOND TEAM DEFINITION BEGIN"
	}

	use "$data/regression_sample.dta", clear
	keep if calyr==2000 & pnlcase==1

	**************************************************************************************
	*Team Definition: when coworkers are in the same firm (1) and when they're in the same firm and occupation (2)
	**************************************************************************************

	if `g'==1{
		egen team`g'=group(betnr) // call a team 1 if working in the same establ
		egen team_tag = tag(betnr) // tags one observation per group
	}

	if `g'==2{
		egen team`g'=group(betnr beruf) // call a team 2 if working in the same establ and occup
		drop if team`g'==.
		egen team_tag = tag(betnr beruf) // tags one observation per group
	}


	* Drop size 1 teams
	bys team`g': gen teamsize=_N // teamsize
	label var teamsize "Team size"
	gen teamsize_l = log(teamsize)
	bys persnr: gen t2 =(teamsize>1)
	keep if t2==1
	count
	drop t2
*/
	*************************************************************************************
	*** 1) Size Statistics
	*************************************************************************************

	*** Count teams and team size distribution
	bys team`g': gen fre2=_N // number of workers in each team in 2000
	label var fre2 "Team size"
	display "Number of Different Teams"
	count if team_tag==1 // # of teams with size >1
	count if team_tag==1 & fre2>2 // with size >2

	display "Unweighted Size Distribution and Histogram"
	tabstat fre2 if team_tag==1, stat(mean sd p10 p50 p90 N)
	twoway__histogram_gen fre2 if team_tag==1 & fre2<100, gen(n_obs bin_fre2) bin(25) frequency
	twoway__histogram_gen fre2 if team_tag==1 & fre2<100, gen(dens x) bin(25) dens
	display _newline "List for Team Size Histogram, size 2-99 (note: same as est size under team def 1). Unweighted."
	list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
	drop n_obs bin_fre2 dens x
	*hist fre2 if team_tag==1 & fre2>2 & fre2<100, bin(25) title("Team size distribution", size(medsmall)) name(team_size_distribution_1, replace) // team`g' size distribution

	twoway__histogram_gen fre2 if fre2<100, gen(n_obs bin_fre2) bin(25) frequency
	twoway__histogram_gen fre2 if fre2<100, gen(dens x) bin(25) dens
	display _newline "List for Team Size Histogram, size 2-99 (note: same as est size under team def 1). Weighted"
	list n_obs dens bin_fre2 if bin_fre2~=., clean N(bin_fre2)
	drop n_obs bin_fre2 dens x
	*hist fre2 if team_tag==1 & fre2>2 & fre2<100, bin(25) title("Team size distribution", size(medsmall)) name(team_size_distribution_1, replace) // team`g' size distribution

	*************************************************************************************
	*** 2) Wage Statistics
	*************************************************************************************

	*** Wage Distribution
	tabstat avw,  stat(mean sd p10 p50 p90 N)
	twoway__histogram_gen avw, gen(n_obs bin_avw) bin(100) frequency
	twoway__histogram_gen avw, gen(dens x) bin(100) dens
	display _newline "List for Wage Histogram"
	list n_obs dens bin_avw if bin_avw~=., clean N(bin_avw)
	drop n_obs bin_avw dens x
	*hist avw, bin(100) title("Wage distribution", size(medsmall)) name(wage_distribution_1, replace) // wage distribution

	*** Between-Within Variance
	display _newline "Regression to compute within team vs between team wage var"
	xtreg avw, i(team`g')

	mat define sigma_u = `e(sigma_u)'
	mat define sigma_e = `e(sigma_e)'
	mat define rho = `e(rho)' // note: rho takes the ratio to the between group variance to total variance  (where total variance is within group plus between group)
	mat define obs = `e(N)'

	matrix variance = [sigma_u \ sigma_e \ rho \ obs]
	matrix rownames variance = "within teams" "between teams" "frac within" "n obs"
	matrix list variance, title(team wage variance decomposition)

	*** Wage Moments
	* 1st Moment
	bys team`g': egen wage_t=mean(avw) // mean wage by team
	label var wage_t "Mean team wage"
	gen wage_t_l = log(wage_t)

	twoway__histogram_gen wage_t if team_tag==1, gen(n_obs bin_wage_t) bin(25) frequency
	twoway__histogram_gen wage_t if team_tag==1, gen(dens x) bin(25) dens
	display _newline "List for Team Wage Histogram"
	list n_obs dens bin_wage_t if bin_wage_t~=., clean N(bin_wage_t)
	drop n_obs bin_wage_t dens x
	*hist wage_t if team_tag==1, bin(25) title("Team wage distribution, unweighted, team def. `g'", size(medsmall)) name(team_wage_dist_unweighted_`g', replace) // team wage distribution

	* 2nd Moment
	bys team`g': egen wage_t_sd=sd(avw) // wage dispersion by team
	label var wage_t_sd "Sd team wage"
	gen wage_t_sd_l = log(wage_t_sd)

	display _newline "List for Team Wage Dispersion Histogram (unweighted)"
	twoway__histogram_gen wage_t_sd if team_tag==1, gen(n_obs bin_wage_t_sd) bin (25) frequency
	twoway__histogram_gen wage_t_sd if team_tag==1, gen(dens x) bin(25)  dens
	list n_obs dens bin_wage_t_sd if bin_wage_t_sd~=., clean N(bin_wage_t_sd)
	drop n_obs bin_wage_t_sd dens x

	* 3rd Moment: Can alternatively just use skewness
	bys team`g': egen wage_t_median=median(avw)
	label var wage_t_median "Median team wage"
	gen mean_median=wage_t/wage_t_median
	label var mean_median "Mean median ratio"
	replace mean_median=.n if mean_median==0
	gen mean_median_l = log(mean_median)

	* Max
	bys team`g': egen wage_t_max=max(avw)
	label var wage_t_max "Max wage in team"
	gen wage_t_max_l = log(wage_t_max)

	* Distribution of Moments
	tabstat wage_t wage_t_sd wage_t_median wage_t_max if team_tag==1,  stat(mean sd p10 p50 p90 N) col(stats) varwidth(13)

	* Correlations of summary stats at the team level
	display _newline "Cross-Correlations"
	pwcorr wage_t wage_t_sd mean_median teamsize wage_t_max if team_tag==1
	matrix C = r(C)
	matrix N = r(N)
	matrix colnames C = wage_t wage_t_sd mean_median teamsize wage_t_max
	matrix rownames C = wage_t wage_t_sd mean_median teamsize wage_t_max
	matrix list N, title(n of observations for above correlation table)
	display _newline "Cross-Correlations in logs"

	pwcorr wage_t_l wage_t_sd_l mean_median_l teamsize_l wage_t_max_l if team_tag==1
	matrix C_l = r(C)
	matrix N_l=r(N)
	matrix colnames C_l = log_wage_t log_wage_t_sd log_mean_median log_teamsize log_wage_t_max
	matrix rownames C_l = log_wage_t log_wage_t_sd log_mean_median log_teamsize log_wage_t_max
	matrix list N_l, title(n of observations for above correlation table)

	display _newline "Wage growth 1, 3, 5, 10 years ahead"
	tabstat wg1 wg3 wg5 wg10, stat(mean sd p10 p50 p90 N) col(stats)
	}
	
	// note: the next block only runs after running file 5_c once (which works after runnning 5_b up to here and then 5b2) - We put the next block here so all summary stats are generated by this file.
/*
		/* Gap-to-Coworker Distribution  for Both Team Def in 2000*/
		use "$data/coworkers_f.dta", clear
		keep if calyr==2000 & pnlcase==1
		tabstat fe_2_l, stat(mean sd p10 p50 p90 N)
		display _newline "List for Log Wage Diff to Avg Coworker in 2000"
		twoway__histogram_gen fe_2_l, bin(25) gen(n_obs bin_fe_2_l) frequency
		twoway__histogram_gen fe_2_l, bin(25) gen(dens x) dens
		list n_obs dens bin_fe_2_l if bin_fe_2_l~=., clean N(bin_fe_2_l)
		drop n_obs bin_fe_2_l dens x
		
		use "$data/coworkers_fo.dta", clear
		keep if calyr==2000 & pnlcase==1
		tabstat fe_2_l, stat(mean sd p10 p50 p90 N)
		display _newline "List for Log Wage Diff to Avg Coworker in 2000"
		twoway__histogram_gen fe_2_l, bin(25) gen(n_obs bin_fe_2_l) frequency
		twoway__histogram_gen fe_2_l, bin(25) gen(dens x) dens
		list n_obs dens bin_fe_2_l if bin_fe_2_l~=., clean N(bin_fe_2_l)
		drop n_obs bin_fe_2_l dens x

		********
		* Additional Results
		********
		
		* Report the fraction of top-coded spells in the annual regression sample
		use "$data/regression_sample.dta", clear
		sum cens if calyr==2000
		sum cens

		
		