* File of the Project "1153" - 5b2.do
* Content: Identify pseudo-death events: Prime age workers permanently (and suddenly) "disappear"
			*then compute for each team the total wage bill and number of the workers lost
			*this is an input into the death-IV constructed in file 5c
clear
cap log close

log using "$log/5_coworkers_b2.log", replace
			
use "$data/monthly.dta", clear

gen calmn=month(stichtag)
gen calyr=year(stichtag)
gen caldate=mofd(stichtag)
sort persnr caldate

gen age=calyr-gebjahr

// this creates a variable that, for each person indicates the last moth where we see them employed (erwstat\geq101), s.t. additional sample restrictions
gen cc3=1 if erwstat>=101
bys persnr: gen cc4=sum(cc3)
bys persnr: egen cc5=max(cc4)
gen lastdum=0
replace lastdum=1 if cc5==cc4 & erwstat==101 & calyr<2009 & age<55 & age>25 // indicate all prime-age exiters, who leave full time work permanently (at least 2 years)
*replace lastdum=1 if cc5==cc4 & grund==49 & erwstat==101 // indicate all prime-age exiters, who leave full time work permanently (at least 2 years)

count if lastdum==1

// iumpose the additional assumption that they have been employed (erwstat>=101) nonstop for at least 2 years at exit
gen cont_emp=0 if lastdum==1
replace cont_emp=1 if cc4-cc4[_n-24]==24 & lastdum==1 & caldate-caldate[_n-24]==24

count if cont_emp==1

// we are working with monthly dataset but want to make sure only to register exits that happen from the january employer (since that is the employer we register as the employer in the annual dataset)
bys persnr calyr: egen hoy=max(lastdum) // select year where exit occurs
keep if hoy==1 // keep only person year observations for exit year
gen demp=lastdum*betnr // identify the firm at exit
gen janemp=betnr if calmn==1 // identify the firm in january (which we select as the year employer)
bys persnr calyr: egen cont_emp2=max(cont_emp) //assign to the whole year the cont_emp indicator
bys persnr calyr: egen janemp2=max(janemp) // assign for the whole year the january employer
bys persnr calyr: egen demp2=max(demp) // assign for the whole year the employer at exit
count if calmn==1 
count if janemp2==demp2 & calmn==1 // ratio shows frac of people that "die" at their january team

keep if janemp2==demp2 & calmn==1 // just keep observations where the job loss is actually at the january employer

keep persnr calyr cont_emp2

save "$data/thedying.dta", replace // dataset with person year observations for those that "die" and additional cont_emp2 indicator

// now merge this to the regression sample
use "$data/regression_sample.dta", clear

*xtset persnr caldate, monthly
sort persnr calyr

merge 1:1 persnr calyr using "$data/thedying.dta"

gen lastdum=1 if _merge==3 // those in the using dataset ( all "die")
gen hclost=avw*lastdum // total wage bill of the "dying"

gen lastdum2=1 if cont_emp2==1 & _merge==3 // addtl pre-death employment restriction
gen hclost2=avw*lastdum2 // wages of the "dying" w/ addtl restriction

// now we count for all firm years (teams) the total wage bill and number of the dying 
preserve
collapse (sum) hclost lastdum hclost2 lastdum2 , by(betnr calyr) // sums the total wage bill and total number of they dying in establishment
*tsset betnr calyr
gen hclost_tot=hclost
gen n_death=lastdum
gen hclost_tot2=hclost2
gen n_death2=lastdum2
drop hclost lastdum hclost2 lastdum2
save "$data/death.dta", replace //dataset has number of dying and their total wage bill  at establishment level for the two death definitions
restore

// now same thing but with establishment occupation teams
collapse (sum) hclost lastdum hclost2 lastdum2 , by(betnr beruf calyr)
*tsset betnr calyr
gen hclost_tot=hclost
gen n_death=lastdum
gen hclost_tot2=hclost2
gen n_death2=lastdum2
drop hclost lastdum hclost2 lastdum2
save "$data/death2.dta", replace
