* File of the Project "1153" - 5_coworkFers.do
* Content: 	Construct summary stats for teams (size, average wages, wage distribution...)
*			4) Construct on ind level: Proxies for coworker quality (avg wage) and compute summary stats for those and for wage growth on ind level

clear
set more off
cap log close

log using "$log/5_coworkers_c.log", replace

******************************************************************************************
* Constructing Peer Groups, Computing Summary Stats, and Adding additional Info for Regressions
******************************************************************************************
local cut "1 2"
foreach g of local cut{

if `g'==2{
	display _newline "THIS IS WHERE THE RESULTS FOR SECOND TEAM DEFINITION BEGIN"
	}

	use "$data/regression_sample.dta", clear

	**************************************************************************************
	*Team Definition: when coworkers are in the same firm (1) and when they're in the same firm and occupation (2)
	**************************************************************************************


	if `g'==1{
		egen team`g'=group(betnr calyr) // call a team 1 if working in the same establ
		drop if team`g'==.
		merge m:1 betnr calyr using "$data/death.dta" //team-level variables: how many workers "die" in any given year and whats their total wages. Lose death definition
		}

	if `g'==2{
		egen team`g'=group(betnr beruf calyr) // call a team 2 if working in the same establ and occup
		drop if team`g'==.
		merge m:1 betnr beruf calyr using "$data/death2.dta" //team-level variables: how many workers "die" in any given year and whats their total wages. Lose death definition
	}

	keep if pnlcase==1 & calyr>1998 & calyr<2010 // we have all the workers that worked during 1999 and 2009 at a panel case establishment
	tsset persnr calyr

	***********************************************
	*** Key Variables for Regressions: Log of Mean Peer Wage and Wages Going Forward
	***********************************************

	* Team Size
	bys team`g': gen teamsize=_N
	label var teamsize "Team size"
	gen ltsize=log(teamsize)
	label var ltsize "Log Size"

	* Drop observation where there is only one worker per team
	gen teamsize_l = log(teamsize)
	bys persnr: gen t2 =(teamsize>1)
	keep if t2==1
	count
	drop t2

	* Average Team Wage
	bys team`g': egen wage_t=mean(avw)
	label var wage_t "Mean team wage"

	*Leave Out Mean (Take out the Own Effect from Team Mean Wage)
	gen fe_2=((wage_t*teamsize)-avw)/(teamsize-1)

	*Construct variable that captures distance to team`g' average quality
	gen fe_2_l=log(fe_2)-log(avw)
	label var fe_2_l "Gap to team quality"
	
	* Log Measures
	gen lavw=log(avw)
	label var lavw "Log Wage"
	gen lfe_2=log(fe_2)
	label var lfe_2 "Log Leave-out Mean"
	local dur "1 2 3 5 10"
	foreach d of local dur{
	gen lwf`d'=log(wf`d')
	label var lwf`d' "Log Wage `d' years later"
	}

	***********************************************
	*** Constructing the Instrument
	***********************************************
	
	** compute counterfactual coworker pay subtracting those who die
	*  wider definition
	gen fe_2_cf=(fe_2*(teamsize-1)-hclost_tot)/(-n_death+teamsize-1) if n_death>0 // subtract the hc of those that leave this year and compute a counterfactual peer w/o them
	replace fe_2_cf=.n if fe_2_cf==fe_2 // | lastdum==1
	gen hclost=log(fe_2/fe_2_cf) // this is positive if avg peer is better with stayers than w/o
	sum hclost, det // since this is avg./med. quite negative it suggests that leavers are selected from the bottom of the within-team wage distribtuion
	sort persnr calyr

	*  narrower definition
	gen fe_2_cf2=(fe_2*(teamsize-1)-hclost_tot2)/(-n_death2+teamsize-1) if n_death2>0 // subtract the hc of those that leave this year and compute a counterfactual peer w/o them
	replace fe_2_cf2=.n if fe_2_cf2==fe_2 // | lastdum==1
	gen hclost2=log(fe_2/fe_2_cf2) // this is positive if avg peer is better with stayers than w/o
	sum hclost2, det // since this is avg./med. quite negative it suggests that leavers are selected from the bottom of the within-team wage distribtuion
	sort persnr calyr

	*********************************************************
	** More and less well paid coworkers separately
	**********************************************************
	
	* Construct wage rank from lowest to highest wage
	sort team`g' avw persnr
	bys team`g': gen tag_equal = 1 if avw[_n]==avw[_n-1]	// tag people that have the same wage
	gen help = 1 if tag_equal!=1
	bys team`g':gen wrank=sum(help)	// people with the same wage have the same rank

	* Generate number and fraction of team members below
	bys team`g': gen num=_n
	gen n_below=num-1 if tag_equal!=1 // number of people with a wage lower than that person
	label var n_below "N of people with lower wages in team"
	bys team`g': replace n_below=n_below[_n-1] if n_below==.
	gen frac_below=n_below/(teamsize-1)
	label var frac_below "frac of people with lower wages in team"

	* Generate average wage below a person
	bys team`g': gen wsum=sum(avw) // cumulative sum
	bys team`g': gen wsum2=wsum[_n-1] if tag_equal!=1
	gen wbar_l=wsum2/n_below if tag_equal!=1		// average wage below a person
	label var wbar_l "Average of wages below"
	bys team`g': replace wbar_l=wbar_l[_n-1] if wbar_l==.

	gen lwl=log(wbar_l)
	label var lwl "$\bar{w}^-$"

	drop help* tag_equal wrank wsum* num

	
	***********************************************************
	** Create number and fraction of peers above and their average wage
	***********************************************************
	
	* Generate wage rank from highest to lowest wage
	gen neg_w=-avw
	sort team`g' neg_w persnr
	bys team`g': gen tag_equal = 1 if avw[_n]==avw[_n-1]	// tag people that have the same wage
	gen help = 1 if tag_equal!=1
	bys team`g':gen wrank=sum(help)	// wage rank in team. people with the same wage have the same rank

	* Generate number and fraction of team members above
	bys team`g': gen num=_n
	gen n_above=num-1 if tag_equal!=1 // number of people with a wage higher than that person
	label var n_below "N of people with higher wages in team"
	bys team`g': replace n_above=n_above[_n-1] if n_above==.
	gen frac_above=n_above/(teamsize-1)

	* Generate average wage above a person
	bys team`g': gen wsum=sum(avw) // cumulative sum
	bys team`g': gen wsum2=wsum[_n-1] if tag_equal!=1
	gen wbar_h=wsum2/n_above if tag_equal!=1		// average wage above a person
	label var wbar_h "Average of wages above"
	bys team`g': replace wbar_h=wbar_h[_n-1] if wbar_h==.

	gen lwh=log(wbar_h)
	label var lwh "$\bar{w}^+$"

	display _newline "n and fractions of team members with a higher (lower) wage" _newline "and average of wages above and below"
	tabstat n_above frac_above wbar_h n_below frac_below wbar_l, stat(mean sd p10 p50 p90 N) col(stats)

	
	*********************************************************
	*** Average Wage of Managers and Workers (all, above, below) weighted and unweighted 
	*********************************************************
	
	if `g'==1{
	gsort team1 -avw
	gen mngr=0
	gen wu_w=0
	gen wu_m=0
	gen nu_w=0
	gen nu_m=0
	gen wd_w=0
	gen wd_m=0
	gen nd_w=0
	gen nd_m=0
	replace mngr=1 if ((beruf>750 & beruf<754)| (beruf>760 & beruf<764) ) // here we classify who is a manager, everyone else worker
	gen wrkr=1-mngr

	** All managers and workers
	bys team1: egen mw_wrkr=mean(avw) if wrkr==1
	bys team1: egen mw_mngr=mean(avw) if mngr==1
	bys team1: egen mw_wrkr2=max(mw_wrkr)
	bys team1: egen mw_mngr2=max(mw_mngr)
	gen lw_mngr=log(mw_mngr2)
	gen lw_wrkr=log(mw_wrkr2)
	
	bys team1: egen sh_w=sum(wrkr/teamsize)
	bys team1: egen sh_m=sum(mngr/teamsize)
	gen lw_mngr_w=sh_m*lw_mngr
	gen lw_wrkr_w=sh_w*lw_wrkr
	
	label var lw_mngr "$\bar{w}_mngr$"
	label var lw_wrkr "$\bar{w}_wrkr$"
	label var lw_mngr_w "$\bar{w}_mngr_weighted$"
	label var lw_wrkr_w "$\bar{w}_wrkr_weighted$"	
		
	** Now only those above	
	gen w_w=avw*wrkr
	gen w_m=avw*mngr
	bys team1: replace wu_w=sum(w_w)-w_w
	by team1: replace wu_m=sum(w_m)-w_m
	by team1: replace nu_m=sum(mngr)-mngr
	by team1: replace nu_w=sum(wrkr)-wrkr
	gen lwh_mngr=log(wu_m/nu_m)
	gen lwh_wrkr=log(wu_w/nu_w)
	
	* the next block eliminates the above variable for those at the top of the team and deals with identical wages
	gen wequal=1 if avw==avw[_n-1]
	gsort team1 mngr avw -lwh_wrkr
	replace lwh_wrkr=lwh_wrkr[_n-1] if wequal==1
	gsort team1 mngr avw -lwh_mngr
	replace lwh_mngr=lwh_mngr[_n-1] if wequal==1

	by team1 mngr: gen help1=_n
	by team1 mngr: gen help2=_N
	gen help3=1 if help2==help1
	by team1: gen maxw_w=avw if wrkr==1 & help3==1
	by team1: gen maxw_m=avw if wrkr==0 & help3==1
	by team1: egen maxw_w2=max(maxw_w)
	by team1: egen maxw_m2=max(maxw_m)
	replace lwh_wrkr=. if avw==maxw_w2
	replace lwh_mngr=. if avw==maxw_m2
	drop help*
	
	label var lwh_mngr "$\bar{w}^+_mngr$"
	label var lwh_wrkr "$\bar{w}^+_wrkr$"
	
	* Weighted by the relative size of workers and managers above
	gen lwh_mngr_w=lwh_mngr*nu_m/(teamsize-1)
	gen lwh_wrkr_w=lwh_wrkr*nu_w/(teamsize-1)

	label var lwh_mngr_w "$\bar{w}^+_mngr_wght$"
	label var lwh_wrkr_w "$\bar{w}^+_wrkr_wght$"
	
	* different weights (not person, but rather establishment specific)
	gen lwh_mngr_w2=lwh_mngr*sh_m
	gen lwh_wrkr_w2=lwh_wrkr*sh_w

	label var lwh_mngr_w2 "$\bar{w}^+_mngr_fix-wght$"
	label var lwh_wrkr_w2 "$\bar{w}^+_wrkr_fix-wght$"
	
	** workers and managers below only	
	drop wequal
	gen wequal=1 if avw==avw[_n-1]
	gsort team1 avw
	bys team1: replace wd_w=sum(w_w)-w_w
	by team1: replace wd_m=sum(w_m)-w_m
	by team1: replace nd_m=sum(mngr)-mngr
	by team1: replace nd_w=sum(wrkr)-wrkr
	gen lwl_mngr=log(wd_m/nd_m)
	gen lwl_wrkr=log(wd_w/nd_w)
	
	label var lwl_mngr "$\bar{w}^-_mngr$"
	label var lwl_wrkr "$\bar{w}^-_wrkr$"

	* the next block eliminates the below variable for those at the bottom of the team and deals with identical wages
	gsort team1 mngr avw lwl_wrkr
	replace lwl_wrkr=lwl_wrkr[_n-1] if wequal==1
	gsort team1 mngr avw lwl_mngr
	replace lwl_mngr=lwl_mngr[_n-1] if wequal==1

	by team1 mngr: gen help1=_n
	by team1: gen minw_w=avw if wrkr==1 & help1==1
	by team1: gen minw_m=avw if wrkr==0 & help1==1
	by team1: egen minw_w2=max(minw_w)
	by team1: egen minw_m2=max(minw_m)
	replace lwl_wrkr=. if avw==minw_w2
	replace lwl_mngr=. if avw==minw_m2
	replace lwl_wrkr=. if (avw==minw_m2 & minw_m2<minw_w2)
	replace lwl_mngr=. if (avw==minw_w2 & minw_m2>minw_w2)
	label var lwl_mngr "$\bar{w}^-_mngr$"
	label var lwl_wrkr "$\bar{w}^-_wrkr$"
	
	* weighted by the relative size of workers and managers above
	gen lwl_mngr_w=lwl_mngr*nd_m/(teamsize-1)
	gen lwl_wrkr_w=lwl_wrkr*nd_w/(teamsize-1)

	label var lwl_mngr_w "$\bar{w}^-_mngr_wght$"
	label var lwl_wrkr_w "$\bar{w}^-_wrkr_wght$"
	
	* alternative (fixed) weights
	gen lwl_mngr_w2=lwl_mngr*sh_m
	gen lwl_wrkr_w2=lwl_wrkr*sh_w

	label var lwl_mngr_w2 "$\bar{w}^-_mngr_fix-wght$"
	label var lwl_wrkr_w2 "$\bar{w}^-_wrkr_fix-wght$"
	}
	
	***********************************************************
	** Compute various moments of the within team wage distribtuon
	***********************************************************
	
	quietly{
	*** Generate moments
	bys team`g' calyr: egen ltsd=sd(lavw)
	label var ltsd "Wage Dispersion"
	bys team`g' calyr: egen wage_t_median=median(avw)
	bys team`g' calyr: gen ltsk=log(wage_t/wage_t_median)
	label var ltsk "Mean-Median"
	gen ltnumh=log(n_above)
	label var ltnumh "\# Above"
	label var frac_above "\% Above"
}
*}	
	***********************************************************
	** Compute total wage bill and employment at the firm level (regression controls)
	***********************************************************
	
	drop _merge
	preserve
	gen employment=1
	collapse (sum) employment avw, by(betnr calyr) 
	rename avw wagebill
	keep betnr calyr employment wagebill
	tsset betnr calyr
	bys betnr: gen empgrowth=F.employment/employment-1
	bys betnr: gen empgrowth2=employment/L.employment-1
	bys betnr: gen empgrowth3=L.employment/L2.employment-1
	bys betnr: gen wbgrowth=F.wagebill/wagebill-1
	bys betnr: gen wbgrowth2=wagebill/L.wagebill-1
	bys betnr: gen wbgrowth3=L.wagebill/L2.wagebill-1
	sum empgrowth* wbgrowth*
	save "$data/firmgrowth.dta", replace
	restore
	merge m:1 betnr calyr using "$data/firmgrowth.dta"


	***********************************************************
	** Fraction of peers in brackets around w_i for nonparametric approximation
	***********************************************************

    ** We compute the fraction of teammates that have at least low% lower wages, high% percent higher wages or fall into 9 symmetrically spaced bins in between

	gen wage_exists=avw!=.n
	bys team`g': egen num_wage_exists=sum(wage_exists)

	local eps=.000001
	local low=-.45
	local high=.45
	local nbin=11
	local step=.1
	quietly{
	gen low=0
	gen high=(1+`low')*avw
	rangestat (sum) pdf1=wage_exists, interval(avw low high) by(team`g') excludeself
	local nm=2
	forval in=`low'(`step')`high'{
	replace low=(1+`in')*avw
	replace high=(1+`in'+`step')*avw-`eps'
	rangestat (sum) pdf`nm'=wage_exists, interval(avw low high) by(team`g') excludeself
	local nm=`nm'+1
	}
	replace low=(1+`high')*avw
	replace high=.
	rangestat (sum) pdf11=wage_exists, interval(avw low high) by(team`g') excludeself
	forval i=1/`nbin'{
	replace pdf`i'=0 if pdf`i'==. &avw!=.
	replace pdf`i'=100*(pdf`i'/(num_wage_exists-1))
	}
	drop wage_exists* num_wage_exists* low high
	}
	noi sum pdf*
	forval ii=1/11{
	label var pdf`ii' "\$p_`ii'$"
	}

	
	***********************************************************
	** NEXT BLOCK NEEDS TO BE CLEANED UP
	***********************************************************
	
	drop help* tag_equal wrank wsum* num* neg_w

	sort persnr calyr
	compress
	
	if `g'==1{

		drop _merge
		
		save "$data/coworkers_f.dta", replace
		
	}
	if `g'==2{

	************************************************************
	********* Merge with The Coworker F dataset to create variables that capture mean wage in team2 and mean wgae in team3 (which is your peers in the same establishment but in different occupations)
	************************************************************

	rename wbar_h wbar_h2
	rename wbar_l wbar_l2
	rename teamsize teamsize2
	rename wage_t wage_t2
	rename n_below n_below2
	rename n_above n_above2

	drop _merge

	merge 1:1 persnr calyr using "$data/coworkers_f.dta"

	rename wbar_h wbar_h1
	rename wbar_l wbar_l1
	rename teamsize teamsize1
	rename wage_t wage_t1
	rename n_below n_below1
	rename n_above n_above1

	*Create average wage, av. wage above and av. wage below for the people in team3=team1-team2, i.e. those in same establishment but different occ
	
	*unweighted
	*bys persnr calyr: gen wage_t3 = (teamsize1*wage_t1-teamsize2*wage_t2)/(teamsize1-teamsize2)   //average wage in t3
	bys persnr calyr: gen wbar_h3 = (n_above1*wbar_h1-n_above2*wbar_h2)/(n_above1-n_above2)  // average wage among higher paid in team 3
	bys persnr calyr: gen wbar_l3 = (n_below1*wbar_l1-n_below2*wbar_l2)/(n_below1-n_below2)  // same for lower paid

	*weighted (same within teams)
	gen sh_3=1-teamsize2/teamsize1
	gen sh_1=1-sh_3
	gen lwh3_w=log(wbar_h3)*sh_3
	gen lwl3_w=log(wbar_l3)*sh_3
	gen lwh1_w=lwh*sh_1
	gen lwl1_w=lwl*sh_1

	label var lwl3 "$\bar{w3}^-$"
	label var lwh3 "$\bar{w3}^+$"
	label var lwl1 "$\bar{w1}^-$"
	label var lwh1 "$\bar{w1}^+$"

	drop if _merge==2 
	drop wbar_h1 wbar_l1 teamsize1 wage_t1 n_below1 n_above1 _merge
	
	rename wbar_h2 wbar_h
	rename wbar_l2 wbar_l
	rename teamsize2 teamsize
	rename wage_t2 wage_t
	rename n_below2 n_below
	rename n_above2 n_above

	save "$data/coworkers_fo.dta", replace
	}
}































