* File of the Project "1153": 7_IV
* Uses the "Pseudo-Death Instrument" constructed in files 5b2 and 5c to instrument for the wedge-to-coworker variable

******************************************************************************************************************
* Note: We run all regressions "quietly" and print the tables in tex format at the end, that's where the # of observations are reported.
******************************************************************************************************************

clear
set more off
cap log close

*net install avar
*net install weakivtest

log using "$log/7_IV.log", replace

set more off, permanently
set linesize 255 // max linesize



local cut "1 2"

foreach g of local cut{

	if `g'==1{
		use "$data/coworkers_f.dta", clear // firm teams
	}

	if `g'==2{
		use "$data/coworkers_fo.dta", clear //firm-occupation teams
		noisily display "Now Team Definition 2"
	}

	*cumulative rather than annual growth
	local dur "2 3 5"
	foreach d of local dur{
	replace wg`d'=(wg`d'+1)^(`d')-1
	}
	
quietly{
sort persnr calyr
tsset persnr calyr
gen rhs=lfe_2-lavw // rhs variable - peers relative to individual (wedge to coworkers)
label var rhs "$\hat{w}$"

bys persnr: gen dlly1=L.hclost // peer human capital lost (last year) due to exit
label var dlly1 "IV1"
bys persnr: gen dlly2=L.hclost2 // tighter exit definition
label var dlly2 "IV2"
bys persnr: gen dwg1=wg1-L.wg1 // first differences
label var wg1 "$\Delta w^1$"
label var dwg1 "D.$\Delta w^1$"
bys persnr: gen drhs=rhs-L.rhs // change in wedge to coworker
label var drhs "D.$\hat{w}$"

// eliminating outliers
local fes "dlly1 dlly2"
foreach c of local fes {
sum `c', det
local lower=r(p1)
local upper=r(p99)
replace `c'=.n if `c'>`upper' | `c'<`lower'
}

***************************************************************
********* OLS, incl. in first differences
****************************************************************

	eststo clear
	eststo growth_wedge_1: reghdfe wg1 rhs if wg1_extr==0, absorb(age_bin ten_bin frau beruf bild calyr) cluster(betnr)
	eststo growth_wedge_fd_1: reg dwg1 drhs if wg1_extr==0, cluster(betnr)

	local dur "2 3 5"
	foreach d of local dur{
		bys persnr: gen dwg`d'=wg`d'-L.wg`d' // first differences at various horizons
	
		eststo growth_wedge_`d': reghdfe wg`d' rhs if wg`d'_extr==0, absorb(age_bin ten_bin frau beruf bild calyr) cluster(betnr)
		eststo growth_wedge_fd_`d': reg dwg`d' drhs if wg`d'_extr==0, cluster(betnr)
	}

********************************************************
********************** IV
********************************************************

* IV1 and IV2 at various horizons
eststo IV1_1: ivreg2 dwg1 (drhs=dlly1) if wg1_extr==0,  cluster(betnr) 
eststo IV2_1: ivreg2 dwg1 (drhs=dlly2)  if wg1_extr==0,  cluster(betnr)  

	local dur "2 3 5"
	foreach d of local dur{
	eststo IV1_`d': ivreg2 dwg`d' (drhs=dlly1) if wg`d'_extr==0,  cluster(betnr) // IV 1, clustered fe
	eststo IV2_`d': ivreg2 dwg`d' (drhs=dlly2)  if wg`d'_extr==0, cluster(betnr)  // IV 2, clustered fe

	}
	
	display "results for team defition `g'"
	esttab growth_wedge_1 growth_wedge_2 growth_wedge_3 growth_wedge_5
	esttab growth_wedge_fd_1 growth_wedge_fd_2 growth_wedge_fd_3 growth_wedge_fd_5
	esttab IV1_1 IV1_2 IV1_3 IV1_5
	esttab IV2_1 IV2_2 IV2_3 IV2_5
	
	esttab growth_wedge_1 growth_wedge_2 growth_wedge_3 growth_wedge_5 using "$log/results_growth_wedge_`g'.tex", 	replace se scalars("r2_within Within \(R^{2}\") label b(a2) noconstant booktabs compress obslast ///
    mgroups("Horizon in Years", pattern(1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nonumbers mtitles("1" "2" "3" "5" "10")
	
	esttab growth_wedge_fd_1 growth_wedge_fd_2 growth_wedge_fd_3 growth_wedge_fd_5 using "$log/results_growth_wedge_fd_`g'.tex", 	replace se scalars("r2_within Within \(R^{2}\") label b(a2) noconstant booktabs compress obslast ///
    mgroups("Horizon in Years", pattern(1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nonumbers mtitles("1" "2" "3" "5" "10")

	esttab IV1_1 IV1_2 IV1_3 IV1_5 using "$log/results_IV1_cl_`g'.tex", 	replace se scalars("cdf C-D F-Stat" "rkf K-P F-Stat") label b(a2) noconstant booktabs compress obslast ///
    mgroups("Horizon in Years", pattern(1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nonumbers mtitles("1" "2" "3" "5" "10")
		
	esttab IV2_1 IV2_2 IV2_3 IV2_5 using "$log/results_IV2_cl_`g'.tex", 	replace se scalars("cdf C-D F-Stat" "rkf K-P F-Stat") label b(a2) noconstant booktabs compress obslast ///
    mgroups("Horizon in Years", pattern(1)  prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
	nonumbers mtitles("1" "2" "3" "5" "10")
	
eststo clear
}	
}


	
	display "*****************************************************"
	display "PRINT ALL TABLES INTO THE LOG FILE"
	display "Note: We print, after the table, the effective F-Stat using the weakivtest command which we run post estimation"
	display "*****************************************************"

	forval g=1/2{

	display _newline
	display "Growth_Wedge_`g'"
	display _newline
	type "$log/results_growth_wedge_`g'.tex"

	display _newline
	display "Growth_Wedge_fd_`g'"
	display _newline
	type "$log/results_growth_wedge_fd_`g'.tex"
	
	display _newline
	display "IV1_clustered_`g'"
	display _newline
	type "$log/results_IV1_cl_`g'.tex"
	
	display _newline
	display "IV2_clustered_`g'"
	display _newline
	type "$log/results_IV2_cl_`g'.tex"
	
	}

