* File of the Project "1153" - 8_estimation.do
* Content: 	1) not run - the first part can be turned on to simulate a dataset for monte carlo (not needed to replicate paper results but useful for training the code)
*			2) the second part creates a dataset for model estimation.
*					it uses the main monthly panel and then selects spells (00-10) that pertain to those establishments that were surveyed throughout
*					as a consequence, we have the full teams in those establishments for all those years

****************************************************************************************
********************PART 1: MONTE CARLO SIMULATION OF A DATASET************************
****************************************************************************************
/*
use "$data/coworkers_f.dta", clear // firm teams
sort calyr betnr avw
egen teamid=group(betnr calyr)
** first we simulate
keep persnr team1 calyr teamid idnum tentgelt beruf betnr age avw2

gen fy=0
bys persnr: replace fy=1 if calyr==1999
bys persnr: egen fyc=max(fy)
drop if fyc==0

local eta_up=.1
local eta_d=.03
local beta=.95
local eps=.001
local alph=.02
local i=10
local noi=.0000000031

tsset persnr calyr

gen z=0
gen Ez=0
gen zu=0
gen zd=0
gen zsum=0
bys teamid: gen ts=_N

replace z=runiform()+1 if calyr==1999

forval i=1999/2010{
sort teamid z
bys teamid: replace zsum=sum(z)
bys teamid: gen tid=_n
bys teamid: replace zd=zsum-z if calyr==`i'
gsort teamid -z
bys teamid: replace zsum=sum(z)
bys teamid: replace zu=zsum-z if calyr==`i'
*replace Ez=1/(ts-1)*((`eta_up')*zu+(`eta_d')*zd)+1/(ts-1)*z*((ts-tid)*(1-`eta_up')+(tid-1)*(1-`eta_d')) if calyr==`i'
replace Ez=1/(ts-1)*((`eta_up')*zu+(`eta_d')*zd-z*((ts-tid)*`eta_up'+(tid-1)*`eta_d'))+z*(1+`alph') if calyr==`i'
sort persnr calyr
replace z= (L.Ez/L.z)*(exp(rnormal(-(`noi'^2)/2,`noi')))*L.z if calyr==`i'+1
display "`i'+1"
drop tid
}

gen avw=z-`beta'*Ez

keep persnr betnr idnum avw avw2 tentgelt calyr beruf age 
drop if calyr<1999 
drop if calyr>2009

egen teamid=group(betnr calyr) //team-year id
bys teamid: gen ts=_N
keep if ts>1 //keep only teams of size>2

drop ts
compress

save "$data/estimation_sample_fake.dta", replace
*/
**********************************************************************************
*************************PART 2: CONSTRUCTING ESTIMATION SAMPLE *******************
********************************************************************************

clear

set more off
cap log close

log using "$log/8_estimation_a_sample.log", replace

local cut "1 2"

foreach g of local cut{

use "$data/annual.dta", clear //
	
keep persnr betnr idnum avw avw2 tentgelt calyr beruf age
drop if calyr<1999 
drop if calyr>2009
******************************************************************************************
* Clean Wage Observations from zeros and outliers
******************************************************************************************

** keep panel cases
merge m:1 idnum using "$orig/iabbp_2008.dta"
gen pnlcase=[pan00_08=="P"] // panel case estbalishment identifiers

keep if pnlcase==1

***** New way, consistent with microdata *****
quietly{
local pay "avw"
foreach p of local pay {

replace `p'=. if `p'==0 //drop 0 wage observations
replace `p'=.n if `p'==.

// drop outliers

foreach yy of numlist 2000/2010{
centile `p' if calyr==`yy', centile(1 99.9)
local lower=r(c_1)
local upper=r(c_2)
replace `p'=.n if `p'<`lower' & `p'!=.n & calyr==`yy'
replace `p'=.n if `p'>`upper' & `p'!=.n & calyr==`yy'
}

}
}
count
drop if avw==.n //throw out observations where wages are unobserved avw is the main variable we are looking at
count

xtset persnr calyr

if `g'==1{
egen teamid=group(betnr calyr) //team-year id
	}
	if `g'==2{
egen teamid=group(betnr beruf calyr) //team-year id for fo
	}

bys teamid: gen ts=_N
keep if ts>1 //keep only teams of size>2

drop ts
compress

if `g'==1{
save "$data/estimation_sample.dta", replace
bys teamid: gen sample=runiform() if _n==1
bys teamid: egen sample2=max(sample)
keep if sample2<.2
save "$data/estimation_sample_small.dta", replace
	}
	if `g'==2{
save "$data/estimation_sample_fo.dta", replace
bys teamid: gen sample=runiform() if _n==1
bys teamid: egen sample2=max(sample)
keep if sample2<.2
save "$data/estimation_sample_fo_small.dta", replace
	}
}
