* File of the Project "1153" - 8_estimation_b2_basic.do
* Content: 	1) This file does exactly the same as file 8_estimation_b2_basic.do except it makes the learning function scale dependend by putting some curvature on the effect of teamsize (see equationn for EZ below)
*			2) The addditional block below loads the results from the basic estimation (for comparison) and then runs an exercise that compares the constructed value of Z in the basleline period with the actual realized PV of income 
			
display "**********************************************************************************"
display "*************************PART 1: ESTIMATING MODEL PARAMTERS *******************"
display "********************************************************************************"

capture log close
log using "$log/8_estimation_basic_curv.log", replace


forval pp=1/2{
if `pp'==1{
use "$data/estimation_sample_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_sample.dta", clear
}

local exponent ".6 .65 .7 .75 .8 .9 1 1.1 1.2" //turn this on to look at different curvature
foreach k of local exponent{
preserve /// need to turn on restore below when running the different experiments

local beta=.95

tsset persnr calyr
sort teamid avw
bys teamid: gen ts=_N
bys teamid: gen tid=_n //TEAM RANK BY WAGE (1 LOWEST)
gen znew=0
gen zu=0
gen zd=0
gen dis=0
gen Ez=0
gen dz=0
gen rhs1=0
gen rhs2=0

		local eta_up=.015
		local eta_d=.005
		local alph=.0001

gen z=avw/(1-`beta') //INITIAL GUESS FOR Z

local eps=.01
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=250
local maxit2=75
local dgs=1000000

timer on 1

while `dis2'>`eps'/30000{ // THE OUTER LOOP RUNS UNITL \ETA_UP AND \ETA_DOWN CONVERGE
local i=30
sort teamid tid

quietly{
while `i'>`eps'{ // THE INNER LOOP RUNS UNTIL Z CONVERGES
by teamid: egen sumz = total(z)
by teamid: replace zd=sum(z)-z
by teamid: replace zu=sumz-zd-z
drop sumz

* CONSTRUCT E[Z'|Z_i,Z_{-i}] GIVEN THE CURRENT ESTIMATES FOR THE LEARNING FUNCTION AND UPDATE Z USING z=w+\beta E[Z'|.]
replace Ez=(1/(ts-1))^`k'*((`eta_up')*zu+(`eta_d')*zd-z*((ts-tid)*`eta_up'+(tid-1)*`eta_d'))+z*(1+`alph')

replace znew=avw+`beta'*Ez
replace dis=abs(znew-z)
replace z=znew

sum(dis)
local i=(r(mean))
local itcount2=`itcount2'+1

* in case z does not converge sufficiently fast
if `itcount2'>`maxit2'{
local i=0
display "went over iteration limit inner loop'"
}
}

local itcount2=0

* Construct Z'-Z and regress on the learning potential to up and down to get updates for eta
sort persnr calyr
bys persnr: replace dz=F1.z/z-1
replace rhs1=(1/(ts-1))^`k'*(zu-z*(ts-tid))/z
replace rhs2=(1/(ts-1))^`k'*(zd-z*(tid-1))/z
quietly reg dz rhs1 rhs2

}
mat aa=e(b)
mat obs = `e(N)'
* this updates eta according to a routine we have found to be working in simulations
local eta_up_n = `eta_up'+.2*(`=aa[1,1]'-`eta_up')+.1*(`=aa[1,2]'-`eta_d')
local eta_d_n = `eta_d'+.2*(`=aa[1,2]'-`eta_d')+.1*(`=aa[1,1]'-`eta_up')
local alph = `alph'+.2*(`=aa[1,3]'-`alph')

local obs =`=obs[1,1]'
display floor(`eta_up_n'*`dgs')/`dgs' "  "  floor(`eta_d_n'*`dgs')/`dgs' "  "  floor(`alph'*`dgs')/`dgs' " Observations: "`obs'

local dis2=abs(`eta_up'-`eta_up_n')+abs(`eta_d'-`eta_d_n')
local eta_up=`eta_up_n'
local eta_d=`eta_d_n'

* in case etas dont converge sufficiently fast
local itcount=`itcount'+1
if `itcount'>`maxit'{
local dis2=0
display "went over iteration limit inner loop'"
}

}

reg dz rhs1 rhs2

gen eta_up_hat=`eta_up'
gen eta_d_hat = `eta_d'
gen alph_hat=`alph'
gen observ=`obs'

sum eta*
sum alph

xtile zpct = z , nquantiles(10)

keep eta* alph* observ dz rhs* teamid
compress

if `pp'==1{
save "$data/estimation_results_fo_curv_`k'.dta", replace
}
else if `pp'==2{
save "$data/estimation_results_curv_`k'.dta", replace
}
restore
}
}


********************************************************************************
************** Load Estimation Results 
********************************************************************************

// get avg teamsize from baseline sample and then adjust coefficients
// estimated parameters (eta..) for the different exponents on size without and with adjustment for mechanical effect.
// also displays the R2 for the different learning functions and the number of observations used in regression
// it does this for 9 different values for the exponent and for each team definition

forval pp=1/2{
local exponent ".6 .65 .7 .75 .8 .9 1 1.1 1.2" //turn this on to look at different curvature
foreach k of local exponent{
quietly{
use "$data/estimation_results_fo.dta", clear
sum ts 
local avgsize_fo=r(mean)
local adjust_fo=(`avgsize_fo'-1)/((`avgsize_fo'-1)^`k') // adjustment for size effect on coefficients

use "$data/estimation_results.dta", clear
sum ts 
local avgsize=r(mean)
local adjust=(`avgsize'-1)/((`avgsize'-1)^`k')
}
if `pp'==1{
use "$data/estimation_results_fo_curv_`k'.dta", clear
quietly reg dz rhs1 rhs2
local r2=e(r2)
local n=e(N)
display"R2: `r2'"
display"Obs used: `n'"
gen eta_up_hat_s=eta_up_hat*`adjust_fo'
gen eta_d_hat_s=eta_d_hat*`adjust_fo'
sum eta*
}
else if `pp'==2{
use "$data/estimation_results_curv_`k'.dta", clear
quietly reg dz rhs1 rhs2
local r2=e(r2)
local n=e(N)
display"R2: `r2'"
display"Obs used: `n'"
gen eta_up_hat_s=eta_up_hat*`adjust'
gen eta_d_hat_s=eta_d_hat*`adjust'
sum eta*
}
}
}

use "$data/estimation_results_fo.dta", clear
tab calyr
use "$data/estimation_results.dta", clear
tab calyr




********************************************************************************
************** Comparing Z with the PV of Income (for Baseline (linear) Model)
********************************************************************************

// This block loads the estimation results for the basic linear learning function and then regresses the present value of wages on the Z (with and without controlling for current wage)

quietly{
forval pp=1/2{

if `pp'==1{
use "$data/estimation_results_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_results.dta", clear
}
reg dz rhs1 rhs2

*keep a workers Z in 1999 and then compare it with the PV of wages (for those that remain continuously employed) in the basic dataset
keep if calyr==1999 
keep persnr z
merge 1:m persnr using "$data/annual.dta"
keep if _merge==3
keep if calyr>1998
replace emp=0 if avw==.
bys persnr: egen totemp=total(emp)
keep if totemp==12

*discounting
gen dsc=1
quietly{
forval i=1/11{
replace dsc=.95^`i' if calyr==1999+`i'
}
}
replace avw=avw*20 if calyr==2010 // make the wage of last year the pv of wages under the assumption that the job lasts forever at this wage (beta=.95))
gen dscavw=dsc*avw // take PV
bys persnr: egen pvinc=total(dscavw)

noi reg pvinc z if calyr==1999
noi reg pvinc avw if calyr==1999
noi reg pvinc z avw if calyr==1999
}
}
