* File of the Project "1153" - 8_estimation_b_basic.do
* Content: 	1) The first part estimates a basic learning function structurally
*			2) The second part reports the parameters estimated structurally in the first part and computes GMM standard errors
*			3) The third part runs the counterfactual exercises reported in the paper


display "**********************************************************************************"
display "*************************PART 1: ESTIMATING MODEL PARAMTERS *******************"
display "********************************************************************************"

capture log close
log using "$log/8_estimation_basic.log", replace


*use "$data/estimation_sample_fake.dta", clear // Turn this on ( that is load the simulated dataset instead of the estimation samples in the next block) to do monte carlo for the estimated dataset

forval pp=1/2{
if `pp'==1{
use "$data/estimation_sample_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_sample.dta", clear
}


local experiment "1"
*local experiment "1 2 3 4 5 6" //turn this on to look at different starting  values and split samples
foreach exper of local experiment{
*preserve /// need to turn on restore below when running the different experiments

local beta=.95

tsset persnr calyr
sort teamid avw
bys teamid: gen ts=_N
bys teamid: gen tid=_n //TEAM RANK BY WAGE (1 LOWEST)
gen znew=0
gen zu=0
gen zd=0
gen dis=0
gen Ez=0
gen dz=0
gen rhs1=0
gen rhs2=0

if `exper'==1{
		local eta_up=.1
		local eta_d=.03
		local alph=.02
}
/*
if `exper'==2{
		local eta_up=.03
		local eta_d=.06
		local alph=.02
}
if `exper'==3{
		local eta_up=.023
		local eta_d=-.05
		local alph=-.01
}
if `exper'==4{
		local eta_up=.08
		local eta_d=.02
		local alph=.001
		drop if calyr>2004
}
if `exper'==5{
		local eta_up=.08
		local eta_d=.02
		local alph=.001
		drop if calyr<2005
}
*/

gen z=avw/(1-`beta') //INITIAL GUESS FOR Z

local eps=.01
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=250
local maxit2=75
local dgs=1000000

timer on 1

while `dis2'>`eps'/30000{ // THE OUTER LOOP RUNS UNITL \ETA_UP AND \ETA_DOWN CONVERGE
local i=30
sort teamid tid

quietly{
while `i'>`eps'{ // THE INNER LOOP RUNS UNTIL Z CONVERGES
by teamid: egen sumz = total(z)
by teamid: replace zd=sum(z)-z
by teamid: replace zu=sumz-zd-z
drop sumz

* CONSTRUCT E[Z'|Z_i,Z_{-i}] GIVEN THE CURRENT ESTIMATES FOR THE LEARNING FUNCTION AND UPDATE Z USING z=w+\beta E[Z'|.]
replace Ez=1/(ts-1)*((`eta_up')*zu+(`eta_d')*zd-z*((ts-tid)*`eta_up'+(tid-1)*`eta_d'))+z*(1+`alph')

replace znew=avw+`beta'*Ez
replace dis=abs(znew-z)
replace z=znew

sum(dis)
local i=(r(mean))
local itcount2=`itcount2'+1

* in case z does not converge sufficiently fast
if `itcount2'>`maxit2'{
local i=0
display "went over iteration limit inner loop'"
}
}

local itcount2=0

* Construct Z'-Z and regress on the learning potential to up and down to get updates for eta
sort persnr calyr
bys persnr: replace dz=F1.z/z-1
replace rhs1=1/(ts-1)*(zu-z*(ts-tid))/z
replace rhs2=1/(ts-1)*(zd-z*(tid-1))/z
quietly reg dz rhs1 rhs2

}
mat aa=e(b)
mat obs = `e(N)'
* this updates eta according to a routine we have found to be working in simulations
local eta_up_n = `eta_up'+.2*(`=aa[1,1]'-`eta_up')+.1*(`=aa[1,2]'-`eta_d')
local eta_d_n = `eta_d'+.2*(`=aa[1,2]'-`eta_d')+.1*(`=aa[1,1]'-`eta_up')
local alph = `alph'+.2*(`=aa[1,3]'-`alph')

local obs =`=obs[1,1]'
display floor(`eta_up_n'*`dgs')/`dgs' "  "  floor(`eta_d_n'*`dgs')/`dgs' "  "  floor(`alph'*`dgs')/`dgs' " Observations: "`obs'

local dis2=abs(`eta_up'-`eta_up_n')+abs(`eta_d'-`eta_d_n')
local eta_up=`eta_up_n'
local eta_d=`eta_d_n'

* in case etas dont converge sufficiently fast
local itcount=`itcount'+1
if `itcount'>`maxit'{
local dis2=0
display "went over iteration limit inner loop'"
}

}

gen eta_up_hat=`eta_up'
gen eta_d_hat = `eta_d'
gen alph_hat=`alph'
gen observ=`obs'

xtile zpct = z , nquantiles(10)

if `exper'==1{
if `pp'==1{
save "$data/estimation_results_fo.dta", replace
}
else if `pp'==2{
save "$data/estimation_results.dta", replace
}
}
*restore
}
}


display "**********************************************************************************"
display "*************************PART 2: Computing Standard Errors *******************"
display "********************************************************************************"


*capture log close
*log using "$log/8_estimation_basic.log", replace

forval pp=1/2{

if `pp'==1{
use "$data/estimation_results_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_results.dta", clear
}

*Parameter estimates along with number of observations saved at the end of the structural estimation part above
sum eta*
sum alph*
sum observ

* This just repeats the final regression in the previous parts, ie it regresses knowledge growth z on the rhs variables (average peer knowledge below and above)
* observe that the regression gives parameter estimates which are identical to the ones printed out in the previous block, that is we have found a fixed point in the estimation.
reg dz rhs1 rhs2
mat define obs = `e(N)'
mat aa=e(b)

**** EXPLANATION OF THE FOLLOWING CODE TO CONSTRUCT GMM STANDARD ERRORS FOR STRUCTURAL ESTIMATION ****
* The next block computes GMM standard errors for the parameters estimated structurally above.
* the notation pretty much follows the Wikipedia notation for GMM:
* we construct auxiliary matrices G and E where
* G stacks the gradient of the moment conditions with respect to parameter pertubations around the point estimates while
* Omega is contains the cross product of the moment conditions
* We then just compute GMM standard errors using the efficient weighting matrix as (G'\Omega^{-1}G)^{-1}
* We save and print, next to the results below, the number of observations that enter the calculation of standard errors

quietly{

* Construct Omega matrix with moment conditions
predict m1, residuals
gen m2=m1*rhs1
gen m3=m1*rhs2

matrix accum R = m1 m2 m3, noconstant deviations
mat Omega=R/obs[1,1]

replace m1=0
replace m2=0
replace m3=0

* pertubation
local dg=.001
mat G=J(3,3,0)

* perturb our three point estimates
forval j=1/3{
quietly{

mat epsg=J(1,3,0)

mat epsg[1,`j']=`dg'

local eta_up = aa[1,1]+epsg[1,1]
local eta_d = aa[1,2]+epsg[1,2]
local alph = aa[1,3]+epsg[1,3]


local eps=.01
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=250
local maxit2=75
local beta=.95
sort teamid tid

* iterate on the Bellman equation until convergence under perturbed parameters
while `i'>`eps'{
by teamid: egen sumz = total(z)
by teamid: replace zd=sum(z)-z
by teamid: replace zu=sumz-zd-z
drop sumz

replace Ez=1/(ts-1)*((`eta_up')*zu+(`eta_d')*zd-z*((ts-tid)*`eta_up'+(tid-1)*`eta_d'))+z*(1+`alph')

replace znew=avw+`beta'*Ez
replace dis=abs(znew-z)
replace z=znew

sum(dis)
local i=(r(mean))
local itcount2=`itcount2'+1

* in case z does not converge sufficiently fast
if `itcount2'>`maxit2'{
local i=0
display "went over iteration limit inner loop'"
}
}

* Now we compute the G matrix, ie the gradient of the moment conditions with respect to the respective parameter
local itcount2=0

* Construct Z'-Z and regress on the learning potential to up and down to get updates for eta
sort persnr calyr
bys persnr: replace dz=F1.z/z-1
replace rhs1=1/(ts-1)*(zu-z*(ts-tid))/z
replace rhs2=1/(ts-1)*(zd-z*(tid-1))/z

replace m1=dz-`alph'-`eta_up'*rhs1-`eta_d'*rhs2
replace m2=m1*rhs1
replace m3=m1*rhs2

sum m1
local xx=r(mean)
mat G[1,`j']=`xx'/`dg'
sum m2
local xx=r(mean)
mat G[2,`j']=`xx'/`dg'
sum m3
local xx=r(mean)
mat G[3,`j']=`xx'/`dg'
}
}
* Record observations used
quietly sum m1
local obs=`e(N)'

* The remainder just constructs GMM Variance matrix using the efficient weighting matrix as
* (G'\Omega^{-1}G)^{-1}

mat Omegainv=syminv(Omega)
mat v_est=((syminv(G'*Omegainv*G))/obs[1,1])

mat sd1=sqrt(v_est[1,1])
mat sd2=sqrt(v_est[2,2])
mat sd3=sqrt(v_est[3,3])


mat list v_est
mat list G
mat list Omega
mat list Omegainv
}

display "Observations Used in the Construction of Standard Errors: `obs'"
display "Standard Errors for \eta_up, \eta_down, \alpha"
mat list sd1
mat list sd2
mat list sd3

***************************************************************************************************************
** Some Easy Things to Compute
** This block runs two exercises on the estimated environment with the piece-wise linear learning function
***************************************************************************************************************

if `pp'==1{
use "$data/estimation_results_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_results.dta", clear
}

*************************************
** A) Flows: Wages vs Learning
** This just computes the average z (ie knowledge) growth as implied by the estimated framework across individuals and years and then averages
*************************************

quietly{
gen dz1=.95*(dz-alph_hat)*z // change in z net of the part that can be attributed to the constant
gen dz2=.95*dz*z // change in z
gen dz3=.95*(Ez-z-alph_hat*z) // predicted z growth (the measure we actually use) net of constant
gen dz4=.95*(Ez-z) // predicted z growth including constant
sum avw if avw>0
sum dz1 if avw>0
sum dz2 if avw>0

** the next block just computes the ration between average knowledge growth and average compensation
sum avw if avw>0
local wmean=r(mean)
local obs=r(N)
sum dz3 if avw>0
local dz3mean=r(mean)
sum dz4 if avw>0
local dz4mean=r(mean)
local zvsw=floor(`dz3mean'/`wmean'*10000)/10000
local zvsw2=floor(`dz4mean'/`wmean'*10000)/10000

** this just compares the variance of compensation (which includes knowledge) with the variance of wages

gen comp=log(avw+dz4)
gen lavw=log(avw)
sum comp if avw>0
local compvar=r(Var)
sum lavw if avw>0
local wagevar=r(Var)

noi display  "This prints our results including the number of observations used"
noi display "Results for All Workers, Observations: `obs'"
noi display "Z growth as fraction of wages without constant : `zvsw'"
noi display _newline
noi display "Z growth as fraction of wages with constant : `zvsw2'"
noi display _newline
noi display "Variance of Log Compensation vs Log Wages: `compvar' vs `wagevar'"


**** this does exactly the same as we just did in the pooled sample but breaking it down by earnings decile
forval i=1/10{
sum avw if avw>0 & zpct==`i'
local wmean=r(mean)
local obs=r(N)
sum dz3 if avw>0 & zpct==`i'
local dz3mean=r(mean)
local zvsw=floor(`dz3mean'/`wmean'*10000)/10000
noi display _newline
noi display "Results for `i'th decile in terms of z, , Observations: `obs'"
noi display "Z growth as fraction of wages without constant : `zvsw'"
}

*************************************
** B) Counterfactal Knowledge Evolution
** This block computes the counterfactual average predicted z growth for the final year in our sample in an experiment where we randomly reshuffle workers across teams holding the size distribution constant
*************************************

** point estimates from the structural estimation
sum eta_up_hat
local eta_up=r(mean)
 sum eta_d_hat
local eta_d=r(mean)
 sum alph_hat
local alph=r(mean)

gen trueEz=Ez

drop Ez zu zd ts* znew tid dis dz

gen znew=0
gen zu=0
gen zd=0
gen dis=0
gen Ez=0
gen dz=0


sum calyr
local maxyear=r(max) // pick the last year in the sample and only keep that year
keep if calyr==`maxyear'
drop if z==.

** this block reshuffles by simply assigning the teamid of the "next" worker
sort calyr persnr
gen teamid_fake=teamid[_n-1] if calyr==`maxyear'
replace teamid=teamid_fake if calyr==`maxyear'

egen teamyr=group(teamid calyr)
egen persyr=group(persnr calyr)

display "`maxyear'"

** now we proceed exactly as before and compute the expected knowledge growth for all individuals given our estimated learning function, the estimated z that we have for all individuals and the new, random team composition

tsset persnr calyr
sort teamyr z

bys teamid: gen ts=_N
bys teamid: gen tid=_n //TEAM RANK BY WAGE (1 LOWEST)

local eps=.0001
local i=10
local dis2=10
local itcount2=0
local maxit2=75
local beta=.95

by teamid: egen sumz = total(z)
by teamid: replace zd=sum(z)-z
by teamid: replace zu=sumz-zd-z
drop sumz

* CONSTRUCT E[Z'|Z_i,Z_{-i}] GIVEN THE CURRENT ESTIMATES FOR THE LEARNING FUNCTION AND UPDATE Z USING z=w+\beta E[Z'|.]
replace Ez=1/(ts-1)*((`eta_up')*zu+(`eta_d')*zd-z*((ts-tid)*`eta_up'+(tid-1)*`eta_d'))+z*(1+`alph')

gen zgold=trueEz-z
gen zgnew=Ez-z
}

**** this is the final results which compute the average change in knowledge z under the baseline and under the counterfactual
sum zgold if calyr==`maxyear'
sum zgnew if calyr==`maxyear'

}
