	* File of the Project "1153" - 8_estimation_pwl.do
* Content of non-commented parts: 	1) Estimate a flexible learning function. The output prints the parameters (and observations used in each step) until convergence.
*`									2) Estimate standard errors using GMM -- for detailed description of the method see comments in code below
*`									3) Run two counterfactual exercises.

display "**********************************************************************************"
display "*************************PART 3: ESTIMATING MODEL PARAMTERS *******************"
display "********************************************************************************"

local fake  "0"
if `fake'==1{
*use "$data/fakedata.dta", clear
use "$data/estimation_sample.dta", clear
gen trueEz2=Ez2
gen truezu=zu
gen truezu2=zu2
gen truezd=zd
gen truets=ts
gen truend=nd
gen truez=z

drop Ez2 Ez zu* zd* n* zsum zd   nu* nd ts* z  zreal teamyr persyr
drop if orig==0
}




capture log close
log using "$log/8_estimation_c_multiplicative.log", replace



forval pp=1/2{

if `pp'==1{
use "$data/estimation_sample_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_sample.dta", clear
}

gen orig=1

local b=1.1
/*
forval bb=1/1{
if `bb'==1{
local b=1.1
}
if `bb'==2{
local b=1.25
}
if `bb'==3{
local b=1.05
}

*/


local beta=.95

tsset persnr calyr
sort teamid avw
bys teamid: gen ts=_N
bys teamid: gen tid=_n //TEAM RANK BY WAGE (1 LOWEST)
bys teamid: gen ts_alt=_N*2

gen z=avw/(1-`beta') //INITIAL GUESS FOR Z

gen znew=0
gen Ez=0
gen Ez2=0
gen zu=0
gen zu2=0
gen zu_temp=0
gen zd=0
gen nup=0
gen nup2=0
gen nup_temp=0
gen nd=0
gen zsum=0
gen zu_alt=0
gen zd_alt=0
gen rhs1=0
gen rhs2=0
gen rhs3=0
gen dis=0
gen dz=0
gen zu1_save=0
gen nup1_save=0


local eta_up_1=.13
local eta_up_2=.08
local eta_d=.01
local alph=.0001
local noi=.00000000001

local eps=.0001
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=150
local maxit2=75
local dgs=1000000

*}

egen teamyr=group(teamid calyr)
egen persyr=group(persnr calyr)


while `dis2'>`eps'/300{ // THE OUTER LOOP RUNS UNITL \ETA_UP AND \ETA_DOWN CONVERGE

local i=30

quietly{

while `i'>`eps'{ // THE INNER LOOP RUNS UNTIL Z CONVERGES

expand 2, gen(dup)
gen zreal=0

replace z=z*`b' if dup==1 // create a duplicate with proportionately higher z
replace orig=(1-dup)
replace zreal=z*(1-dup) // the "real" z (shifted one is ignored)

sort teamyr z

by teamyr: replace nd=sum(orig)-1

replace nup=ts-nd-1
replace nup=nup*(-1) if dup==1

by teamyr: egen sumz = total(zreal)
by teamyr: replace zd=sum(zreal)-z // total z below
replace zu=sumz-zd-z //total z above

replace zu_temp=zu
replace nup_temp=nup
replace zu=zu*(-1) if dup==1 // for the shifted duplicate generate the (negative of) zum of z above

bys persnr calyr: egen zu1=total(zu)  // add up at persnr to get the zu1
by persnr calyr: egen nup1=total(nup)

replace zu2=zu_temp-zu1 if dup==0 // now we have the right split for the original
replace nup2=nup_temp-nup1 if dup==0

replace Ez2=1/(ts-1)*(`eta_up_1'*(zu1-nup1*z)+`eta_up_2'*(zu2-nup2*z)+`eta_d'*(zd-nd*z))+z*(1+`alph')

gsort persnr calyr -z

replace z= (L.Ez2/L.z)*(exp(rnormal(-(`noi'^2)/2,`noi')))*L.z if calyr==`i'+1
replace z=runiform()+1  if z==.

replace znew=avw+`beta'*Ez2

replace dis=abs(znew-z)
replace z=znew

drop if orig==0

*noisily sum(dis) if orig==1
local i=(r(mean))

local itcount2=`itcount2'+1

replace zu1_save=zu1
replace nup1_save=nup1

drop zu1 sumz nup1 dup zreal

* in case z does not converge sufficiently fast
if `itcount2'>`maxit2'{
local i=0
display "went over iteration limit inner loop'"
}
}
}

local itcount2=0

keep if orig==1

gen zu1=zu1_save
gen nup1=nup1_save

* Construct Z'-Z and regress on the learning potential to up and down to get updates for eta
sort persnr calyr
bys persnr: replace dz=F1.z/z-1
*((`eta_up_1')*zu1+(`eta_up_2')*zu2+(`eta_d')*zd-z*nd*`eta_d'-nu1*z*`eta_up_1'-nu2*((z+`b')*`eta_up_2'-`b'*`eta_up_1'))+z*(1+`alph')
replace rhs1=1/(ts-1)*(zu1-z*nup1)/z
replace rhs2=1/(ts-1)*(zu2-z*nup2)/z
replace rhs3=1/(ts-1)*(zd-z*nd)/z
quietly: reg dz rhs1 rhs2 rhs3 if orig==1

mat aa=e(b)
	noisily mat list aa

mat obs = `e(N)'

* this updates eta according to a routine we have found to be working in simulations
local eta_up_1_n = `eta_up_1'+.2*(`=aa[1,1]'-`eta_up_1') ///+.1*(`=aa[1,2]'-`eta_d')

local eta_up_2_n = `eta_up_2'+.2*(`=aa[1,2]'-`eta_up_2') ///+.1*(`=aa[1,2]'-`eta_d')

local eta_d_n = `eta_d'+.2*(`=aa[1,3]'-`eta_d') ///+.1*(`=aa[1,1]'-`eta_up')

local alph = `alph'+.2*(`=aa[1,4]'-`alph')

local obs =`=obs[1,1]'
display floor(`eta_up_1_n'*`dgs')/`dgs' " "floor(`eta_up_2_n'*`dgs')/`dgs'   " "  floor(`eta_d_n'*`dgs')/`dgs' "  "  floor(`alph'*`dgs')/`dgs' " Observations: "`obs'

local dis2=abs(`eta_up_1'-`eta_up_1_n')+abs(`eta_up_2'-`eta_up_2_n')+abs(`eta_d'-`eta_d_n')

local eta_up_1=`eta_up_1_n'
local eta_up_2=`eta_up_2_n'
local eta_d=`eta_d_n'

* in case etas dont converge sufficiently fast
local itcount=`itcount'+1
if `itcount'>`maxit'{
local dis2=0
display "went over iteration limit outer loop'"
}
drop  zu1 nup1
}

gen eta_up_1_hat=`eta_up_1'
gen eta_up_2_hat=`eta_up_2'
gen eta_d_hat = `eta_d'
gen alph_hat=`alph'
gen observ=`obs'

xtile zpct = z , nquantiles(10)



*if `pp'==1 & `bb'==1{

if `pp'==1{
save "$data/estimation_results_mult_fo.dta", replace
}
if `pp'==2{
save "$data/estimation_results_mult.dta", replace
}
timer off 1
timer list 1
*}
}



display "**********************************************************************************"
display "*************************PART 4: Computing Standard Errors *******************"
display "********************************************************************************"


capture log close
log using "$log/8_estimation_c_multiplicative.log", replace


forval pp=1/2{

if `pp'==1{
use "$data/estimation_results_mult_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_results_mult.dta", clear
}

*Parameter estimates along with number of observations used in the structural estimation
sum eta*
sum alph*
sum observ

local b=1.1


reg dz rhs1 rhs2 rhs3
mat define obs = `e(N)'
mat aa=e(b)

**** EXPLANATION OF THE FOLLOWING CODE TO CONSTRUCT GMM STANDARD ERRORS FOR STRUCTURAL ESTIMATION ****
* The next block computes GMM standard errors for the parameters estimated structurally above.
* the notation pretty much follows the Wikipedia notation for GMM:
* we construct auxiliary matrices G and E where
* G stacks the gradient of the moment conditions with respect to parameter pertubations around the point estimates while
* Omega is contains the cross product of the moment conditions
* We then just compute GMM standard errors using the efficient weighting matrix as (G'\Omega^{-1}G)^{-1}
* We save and print, next to the results below, the number of observations that enter the calculation of standard errors
*** for more detailed comments on how the following lines of code implement this see the file 8_estimation_basic.do which implements exactly the same steps

quietly{
predict m1, residuals
gen m2=m1*rhs1
gen m3=m1*rhs2
gen m4=m1*rhs3

matrix accum R = m1 m2 m3 m4, noconstant deviations
mat Omega=R/obs[1,1]

replace m1=0
replace m2=0
replace m3=0
replace m4=0


local dg=.001
mat G=J(4,4,0)

forval j=1/4{
quietly{
mat epsg=J(1,4,0)

mat epsg[1,`j']=`dg'

local eta_up_1 = aa[1,1]+epsg[1,1]
local eta_up_2 = aa[1,2]+epsg[1,2]
local eta_d = aa[1,3]+epsg[1,3]
local alph = aa[1,4]+epsg[1,4]

local eps=.01
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=250
local maxit2=75
local beta=.95

local eps=.0001
local i=10
local dis2=10
local itcount=0
local itcount2=0
local maxit=100
local maxit2=75
local dgs=1000000
local noi=.00000000001


*egen teamyr=group(teamid calyr)
*egen persyr=group(persnr calyr)

while `i'>`eps'{ // THE INNER LOOP RUNS UNTIL Z CONVERGES

expand 2, gen(dup)
gen zreal=0

replace z=z*`b' if dup==1 // create a duplicate with proportionately higher z
replace orig=(1-dup)
replace zreal=z*(1-dup) // the "real" z (shifted one is ignored)

sort teamyr z

by teamyr: replace nd=sum(orig)-1

replace nup=ts-nd-1
replace nup=nup*(-1) if dup==1

by teamyr: egen sumz = total(zreal)
by teamyr: replace zd=sum(zreal)-z // total z below
replace zu=sumz-zd-z //total z above

replace zu_temp=zu
replace nup_temp=nup
replace zu=zu*(-1) if dup==1 // for the shifted duplicate generate the (negative of) zum of z above

bys persnr calyr: egen zu1=total(zu)  // add up at persnr to get the zu1
by persnr calyr: egen nup1=total(nup)

replace zu2=zu_temp-zu1 if dup==0 // now we have the right split for the original
replace nup2=nup_temp-nup1 if dup==0

replace Ez2=1/(ts-1)*(`eta_up_1'*(zu1-nup1*z)+`eta_up_2'*(zu2-nup2*z)+`eta_d'*(zd-nd*z))+z*(1+`alph')

gsort persnr calyr -z

replace z= (L.Ez2/L.z)*(exp(rnormal(-(`noi'^2)/2,`noi')))*L.z if calyr==`i'+1
replace z=runiform()+1  if z==.

replace znew=avw+`beta'*Ez2

replace dis=abs(znew-z)
replace z=znew

drop if orig==0

sum(dis) if orig==1
local i=(r(mean))


local itcount2=`itcount2'+1

replace zu1_save=zu1
replace nup1_save=nup1

drop zu1 sumz nup1 dup zreal

* in case z does not converge sufficiently fast
if `itcount2'>`maxit2'{
local i=0
display "went over iteration limit inner loop'"
}
}


local itcount2=0

keep if orig==1

gen zu1=zu1_save
gen nup1=nup1_save

* Construct Z'-Z and regress on the learning potential to up and down to get updates for eta
sort persnr calyr
bys persnr: replace dz=F1.z/z-1
*((`eta_up_1')*zu1+(`eta_up_2')*zu2+(`eta_d')*zd-z*nd*`eta_d'-nu1*z*`eta_up_1'-nu2*((z+`b')*`eta_up_2'-`b'*`eta_up_1'))+z*(1+`alph')
replace rhs1=1/(ts-1)*(zu1-z*nup1)/z
replace rhs2=1/(ts-1)*(zu2-z*nup2)/z
replace rhs3=1/(ts-1)*(zd-z*nd)/z

replace m1=dz-`alph'-`eta_up_1'*rhs1-`eta_up_2'*rhs2-`eta_d'*rhs3
replace m2=m1*rhs1
replace m3=m1*rhs2
replace m4=m1*rhs3

sum m1
local xx=r(mean)
mat G[1,`j']=`xx'/`dg'
sum m2
local xx=r(mean)
mat G[2,`j']=`xx'/`dg'
sum m3
local xx=r(mean)
mat G[3,`j']=`xx'/`dg'
sum m4
local xx=r(mean)
mat G[4,`j']=`xx'/`dg'
drop zu1 nup1
}
}

quietly sum m1
local obs=`e(N)'

mat Omegainv=syminv(Omega)
mat v_est=((syminv(G'*Omegainv*G))/obs[1,1])

mat sd1=sqrt(v_est[1,1])
mat sd2=sqrt(v_est[2,2])
mat sd3=sqrt(v_est[3,3])
mat sd4=sqrt(v_est[4,4])

}


display "The following prints GMM standard errors for the structural estimation results which are programmed in the previous block"


display "Observations Used in the Construction of Standard Errors: `obs'"

/*
mat list v_est
mat list G
mat list Omega
mat list Omegainv
*/

display "Standard Errors for \eta_up_1, \eta_up_2, \eta_down, \alpha"

mat list sd1
mat list sd2
mat list sd3
mat list sd4

***************************************************************************************************************
** Some Easy Things to Compute
** This block runs two exercises on the estimated environment with the piece-wise linear learning function
***************************************************************************************************************

if `pp'==1{
use "$data/estimation_results_mult_fo.dta", clear
}
else if `pp'==2{
use "$data/estimation_results_mult.dta", clear
}

*************************************
** A) Flows: Wages vs Learning
** This just computes the average z (ie knowledge) growth as implied by the estimated framework across individuals and years and then averages
*************************************

quietly{
gen dz1=.95*(dz-alph_hat)*z // change in z net of the part that can be attributed to the constant
gen dz2=.95*dz*z // change in z
gen dz3=.95*(Ez2-z-alph_hat*z) // predicted z growth (the measure we actually use) net of constant
gen dz4=.95*(Ez2-z) // predicted z growth including constant
sum avw if avw>0
sum dz1 if avw>0
sum dz2 if avw>0

** the next block just computes the ration between average knowledge growth and average compensation
sum avw if avw>0
local wmean=r(mean)
local obs=r(N)
sum dz3 if avw>0
local dz3mean=r(mean)
sum dz4 if avw>0
local dz4mean=r(mean)
local zvsw=floor(`dz3mean'/`wmean'*10000)/10000
local zvsw2=floor(`dz4mean'/`wmean'*10000)/10000

** this just compares the variance of compensation (which includes knowledge) with the variance of wages

gen comp=log(avw+dz4)
gen lavw=log(avw)
sum comp if avw>0
local compvar=r(Var)
sum lavw if avw>0
local wagevar=r(Var)

noi display  "This prints our results including the number of observations used"
noi display "Results for All Workers, Observations: `obs'"
noi display "Z growth as fraction of wages without constant : `zvsw'"
noi display _newline
noi display "Z growth as fraction of wages with constant : `zvsw2'"
noi display _newline
noi display "Variance of Log Compensation vs Log Wages: `compvar' vs `wagevar'"


**** this does exactly the same as we just did in the pooled sample but breaking it down by earnings decile
forval i=1/10{
sum avw if avw>0 & zpct==`i'
local wmean=r(mean)
local obs=r(N)
sum dz3 if avw>0 & zpct==`i'
local dz3mean=r(mean)
local zvsw=floor(`dz3mean'/`wmean'*10000)/10000
noi display _newline
noi display "Results for `i'th decile in terms of z, , Observations: `obs'"
noi display "Z growth as fraction of wages without constant : `zvsw'"
}


*************************************
** B) Counterfactal Knowledge Evolution
** This block computes the counterfactual average predicted z growth for the final year in our sample in an experiment where we randomly reshuffle workers across teams holding the size distribution constant
*************************************

** point estimates from the structural estimation
sum eta_up_1_hat
local eta_up_1=r(mean)
 sum eta_up_2_hat
local eta_up_2=r(mean)
 sum eta_d_hat
local eta_d=r(mean)
 sum alph_hat
local alph=r(mean)

local b=1.1

*quietly{

gen trueEz2=Ez2
/*
gen truezu=zu
gen truezu1=zu1
gen truezu2=zu2
gen truezd=zd
gen truenu1=nu1
gen truenu2=nu2
gen truets=ts
gen truend=nd
gen truez=z
*/
gen truenup=nup
gen truenup2=nup2

drop Ez2 Ez zu* zd* n* zsum zd   nu* nd ts* znew tid teamyr persyr

gen znew=0
gen Ez=0
gen Ez2=0
gen zu=0
gen zu2=0
gen zd=0
gen nu1=0
gen nup2=0
gen nd=0
gen zsum=0
gen zu_alt=0
gen zd_alt=0


sum calyr
local maxyear=r(max) // pick the last year in the sample and only keep that year
keep if calyr==`maxyear'
drop if z==.

** this block reshuffles by simply assigning the teamid of the "next" worker
sort calyr persnr
gen teamid_fake=teamid[_n-1] if calyr==`maxyear'
replace teamid=teamid_fake if calyr==`maxyear'

egen teamyr=group(teamid calyr)
egen persyr=group(persnr calyr)

display "`maxyear'"


** now we proceed exactly as before and compute the expected knowledge growth for all individuals given our estimated learning function, the estimated z that we have for all individuals and the new, random team composition

tsset persnr calyr
sort teamyr avw

bys teamid: gen ts=_N
bys teamid: gen tid=_n //TEAM RANK BY WAGE (1 LOWEST)
bys teamid: gen ts_alt=_N*2

local eps=.0001
local i=10
local dis2=10
local itcount2=0
local maxit2=75
local beta=.95


sum eta_up_1_hat
local eta_up_1=r(mean)
 sum eta_up_2_hat
local eta_up_2=r(mean)
 sum eta_d_hat
local eta_d=r(mean)
 sum alph_hat
local alph=r(mean)

expand 2, gen(dup)
gen zreal=0

replace z=z*`b' if dup==1 // create a duplicate with proportionately higher z
replace orig=(1-dup)
replace zreal=z*(1-dup) // the "real" z (shifted one is ignored)

sort teamyr z

by teamyr: replace nd=sum(orig)-1

gen nup=ts-nd-1
replace nup=nup*(-1) if dup==1

by teamyr: egen sumz = total(zreal)
by teamyr: replace zd=sum(zreal)-z // total z below
replace zu=sumz-zd-z //total z above

gen zu_temp=zu
gen nup_temp=nup
replace zu=zu*(-1) if dup==1 // for the shifted duplicate generate the (negative of) zum of z above

bys persnr calyr: egen zu1=total(zu)  // add up at persnr to get the zu1
by persnr calyr: egen nup1=total(nup)

replace zu2=zu_temp-zu1 if dup==0 // now we have the right split for the original
replace nup2=nup_temp-nup1 if dup==0

replace Ez2=1/(ts-1)*(`eta_up_1'*(zu1-nup1*z)+`eta_up_2'*(zu2-nup2*z)+`eta_d'*(zd-nd*z))+z*(1+`alph')

gen zgold=trueEz2-z
gen zgnew=Ez2-z
}


**** this is the final results which compute the average change in knowledge z under the baseline and under the counterfactual
sum zgold if dup==0 & calyr==`maxyear'
sum zgnew if dup==0 & calyr==`maxyear'
}





